@@ -1197,7 +1197,7 @@ typedef struct {
 	GcrOpenpgpCallback callback;
 	gpointer user_data;
 	guint count;
-	EggBytes *backing;
+	GBytes *backing;
 	GPtrArray *records;
 } openpgp_parse_closure;
 
@@ -1206,7 +1206,7 @@ openpgp_parse_free (gpointer data)
 {
 	openpgp_parse_closure *closure = data;
 	g_ptr_array_unref (closure->records);
-	egg_bytes_unref (closure->backing);
+	g_bytes_unref (closure->backing);
 	g_free (closure);
 }
 
@@ -1215,7 +1215,7 @@ maybe_emit_openpgp_block (openpgp_parse_closure *closure,
                           const guchar *block,
                           const guchar *end)
 {
-	EggBytes *outer;
+	GBytes *outer;
 	gsize length;
 	GPtrArray *records;
 
@@ -1231,17 +1231,17 @@ maybe_emit_openpgp_block (openpgp_parse_closure *closure,
 	records = closure->records;
 	closure->records = g_ptr_array_new_with_free_func (_gcr_record_free);
 
-	outer = egg_bytes_new_with_free_func (block, length, egg_bytes_unref,
-	                                      egg_bytes_ref (closure->backing));
+	outer = g_bytes_new_with_free_func (block, length, (GDestroyNotify)g_bytes_unref,
+	                                      g_bytes_ref (closure->backing));
 	if (closure->callback)
 		(closure->callback) (records, outer, closure->user_data);
-	egg_bytes_unref (outer);
+	g_bytes_unref (outer);
 
 	g_ptr_array_unref (records);
 }
 
 guint
-_gcr_openpgp_parse (EggBytes *data,
+_gcr_openpgp_parse (GBytes *data,
                     GcrOpenpgpParseFlags flags,
                     GcrOpenpgpCallback callback,
                     gpointer user_data)
@@ -1262,14 +1262,14 @@ _gcr_openpgp_parse (EggBytes *data,
 	/* For libgcrypt */
 	_gcr_initialize_library ();
 
-	at = egg_bytes_get_data (data);
-	end = at + egg_bytes_get_size (data);
+	at = g_bytes_get_data (data, NULL);
+	end = at + g_bytes_get_size (data);
 	block = NULL;
 
 	closure = g_new0 (openpgp_parse_closure, 1);
 	closure->callback = callback;
 	closure->user_data = user_data;
-	closure->backing = egg_bytes_ref (data);
+	closure->backing = g_bytes_ref (data);
 	closure->records = g_ptr_array_new_with_free_func (_gcr_record_free);
 
 	while (at != NULL && at != end) {
